pyriskadjust.models package
===========================

Submodules
----------

pyriskadjust.models.model\_2018\_v22 module
-------------------------------------------

.. automodule:: pyriskadjust.models.model_2018_v22
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyriskadjust.models
    :members:
    :undoc-members:
    :show-inheritance:
